from enum import Enum
class ItemPropertyEnum(Enum):
    NAVIG_URL = "navig_url"
    NAVIG_TITLE = "navig_title"
    NAVIG_DATE = "navig_date"
    NAVIG_DEPT = "navig_dept"
    NAVIG_TEXT_NUMBER = "navig_text_number"
    DETAIL_PAGE_URL = "detail_page_url"
    DETAIL_PAGE_TITLE = "detail_page_title"
    DETAIL_PAGE_DEPT = "detail_page_dept"
    DETAIL_PAGE_DATE = "detail_page_date"
    DETAIL_PAGE_TEXT_NUMBER = "detail_page_text_number"
    DETAIL_PAGE_PUNISHED_PARTIES = "detail_page_punished_parties"
    DETAIL_PAGE_PUNISHED_PEOPLE = "detail_page_punished_people"
    DETAIL_PAGE_LAWACCORDING = "detail_page_lawAccording"
    DETAIL_PAGE_PENALTYACCORDING = "detail_page_penaltyAccording"
    DETAIL_PAGE_PUNISHMENT_MEASURES = "detail_page_punishment_measures"
    DETAIL_PAGE_BODY_CODE = "detail_page_body_code"
    DETAIL_PAGE_BODY_IS_TABLE = "detail_page_body_is_table"
    DETAIL_PAGE_SOURCE_CODE = "detail_page_source_code"
    FILE_URLS = "file_urls"
    FILE_NAMES = "file_names"
    FILES = "files"
    FILES_BODY_IS_DOWN = "files_body_is_down"
    FILES_BODY_IS_TABLE = "files_body_is_table"
    FILES_TITLE = "files_title"
    FILES_DATE = "files_date"
    FILES_DEPT = "files_dept"
    FILES_TEXT_NUMBER = "files_text_number"
    FILES_PUNISHED_PARTIES = "files_punished_parties"
    FILES_PUNISHED_PEOPLE = "files_punished_people"
    FILES_LAWACCORDING = "files_lawAccording"
    FILES_PENALTYACCORDING = "files_penaltyAccording"
    FILES_PUNISHMENT_MEASURES = "files_punishment_measures"
    FILES_BODY_CODE = "files_body_code"
    TASK_CODE = "task_code"
    COLLECTION_DATE = "collection_date"
